package com.anabas.pdasharedlet;

/**
 * Title:        SocketHandler.java
 * Description:  Serve each PDA Client by creating input/output stream
 * Copyright:    Copyright (c) 2001
 * Company:      CSIT FSU
 * @author       Sangyoon Oh soh@csit.fsu.edu
 * @version 1.0
 */

import java.io.*;
import java.net.*;

public class SocketHandler extends Thread {

    /**
     *  send out HHMP byte[] over DataOutputStream
     *
     *  @param  HHMP byte[]
     */
    public void sendHHMP(byte[] b) {
      try {
        String temp = new String(b);
        dataOutput.writeInt(temp.length());
        dataOutput.write(b);
      }
      catch(Exception e) {
        e.printStackTrace();
      }
    }

    /**
     *  constructor: create input/output stream
     *
     *  @param   TCPServer as parents and Socket
     */
    public SocketHandler(TCPServer _server, Socket _connection) {
      server = _server;
      incoming = _connection;
      try {
        dataInput = new DataInputStream(incoming.getInputStream());
        dataOutput = new DataOutputStream(incoming.getOutputStream());
      }
      catch(Exception e) {
        e.printStackTrace();
      }
    }

    /**
     *  thread run(): take incoming request and pass it to PAdaptor
     */
    public void run() {
      try {
        boolean stop = false;
        while(!stop) {

          int j = dataInput.readInt();
          byte[] HHms = new byte[j];

          // HHMP size
          int i = dataInput.read(HHms);

          String mid = new String(HHms,0,1);
          this.MACHINEID = mid + "machine";
          String aid = new String(HHms,1,1);
          if(aid.compareTo("0")==0) {
            server.parent.IMhash.put(MACHINEID,this);
            this.APPLICATIONID = "0AC";
          }
          else if(aid.compareTo("1")==0) {
            server.parent.SVGhash.put(MACHINEID,this);
            this.APPLICATIONID = "1AC";
          }
          else if(aid.compareTo("2")==0) {
            server.parent.SDhash.put(MACHINEID,this);
            this.APPLICATIONID = "2AC";
          }
          else if(aid.compareTo("3")==0) {
            server.parent.TextChathash.put(MACHINEID,this);
            this.APPLICATIONID = "3AC";
          }

          if(i != 0) {
            server.parent.getHHMP(HHms, i);
          }
          // if size of HHMP = 0, stop while loop
          else stop = true;
        }
        incoming.close();
      }
      catch(Exception e) {
        System.out.println( "Socket Error &&&&&&&&&" );
        /**
        switch(MACHINEID) {
          case 0:
            server.parent.IMhash.remove(MACHINEID);
        }
        **/
        e.printStackTrace();
        this.destroy();
      }
    }

    public String MACHINEID = null;
    public String APPLICATIONID = null;
    protected Socket incoming;
    protected TCPServer server;
    protected DataInputStream dataInput;
    protected DataOutputStream dataOutput;
}